--[[-----------------------------------------------------------------

EnergyMonitor SimpleTimer library

This library creates a simple countdown based timer.  This timer runs
independently of the "time" source.  Currently used with GetTime()
and UnitPower("player", SPELL_POWER_ENERGY).

Author: lokicoyote
File Date: 2008-11-22T02:59:59Z
File Revision: 66
Project Revision: 73
Project Version: v0.10.4

--]]-----------------------------------------------------------------

local LibStub = assert(LibStub)

-- Cache often used global functions
local pairs = _G.pairs
local floor = _G.math.floor

local kLibrary = "EnergyMonitor_SimpleTimer-1.0"
local kMinor = tonumber(("$Revision: 66 $"):match("(%d+)")) or 0

local lib = LibStub:NewLibrary(kLibrary, kMinor)

if not lib then return end

local timer = {}

function lib:New()
	local t = {}
	for name, func in pairs(timer) do
		t[ name ] = func
	end
	t.var = { length = 1 }
	return t
end

function timer:Start(in_now)
	self.var.start = in_now
	self.var.stop = in_now + self.var.length
end

function timer:Reset(in_now)
	self.var.start = self.var.start + floor((in_now - self.var.start) / self.var.length) * self.var.length
	self.var.stop = self.var.start + self.var.length
end

function timer:IsExpired(in_now)
	return self.var.stop <= in_now
end

function timer:IsStarted(in_now)
	return self.var.start <= in_now
end

---------------------------------------------------------------------
-- Getter and Setter functions
---------------------------------------------------------------------

function timer:SetLength(in_length)
	self.var.length = assert(0 < (in_length or 0) and in_length, "Length must be positive")
	self.var.stop = self.var.start + in_length
end

function timer:GetLength()
	return self.var.length
end

function timer:GetStart()
	return self.var.start
end

function timer:GetRemaining(in_now)
	return self.var.stop - in_now
end

function timer:GetElapsed(in_now)
	return in_now - self.var.start
end
