--[[-----------------------------------------------------------------

EnergyMonitor PlaySound defintions

Registers all the http://www.wowwiki.com/API_PlaySound entries

Author: lokicoyote
File Date: 2008-11-22T09:19:34Z
File Revision: 68
Project Revision: 73
Project Version: v0.10.4

--]]-----------------------------------------------------------------

local kAddon = "EnergyMonitor"

-- Cache often used global functions
local pairs = _G.pairs

---------------------------------------------------------------------
-- Library constants
---------------------------------------------------------------------

local addon = LibStub("AceAddon-3.0"):GetAddon(kAddon .. "_Options")

local kPlaySoundValues = {
	-- FIXME: Localize
	PVPENTERQUEUE = "PVP Enter Queue"
	, PVPTHROUGHQUEUE = "PVP Through Queue"
	, GLUESCREENSMALLBUTTONMOUSEDOWN = "Glue Screen Small Button Mouse Down"
	, GLUESCREENSMALLBUTTONMOUSEUP = "Glue Screen Small Button Mouse Up"
	, GLUESCREENSMALLBUTTONMOUSEOVER = "Glue Screen Small Button Mouse Over"
	, GLUESCREENMEDIUMBUTTONMOUSEDOWN = "Glue Screen Medium Button Mouse Down"
	, GLUESCREENMEDIUMBUTTONMOUSEUP = "Glue Screen Medium Button Mouse Up"
	, GLUESCREENMEDIUMBUTTONMOUSEOVER = "Glue Screen Medium Button Mouse Over"
	, GLUESCREENLARGEBUTTONMOUSEDOWN = "Glue Screen Large Button Mouse Down"
	, GLUESCREENLARGEBUTTONMOUSEUP = "Glue Screen Large Button Mouse Up"
	, GLUESCREENLARGEBUTTONMOUSEOVER = "Glue Screen Large Button Mouse Over"
	, GLUESCREENEDITBOXKEYCLICK = "Glue Screen Edit Box Key Click"
	, GLUECHECKBOXMOUSEDOWN = "Glue Checkbox Mouse Down"
	, GLUECHECKBOXMOUSEUP = "Glue Checkbox Mouse Up"
	, GLUECHECKBOXMOUSEOVER = "Glue Checkbox Mouse Over"
	, GLUECHARCUSTOMIZATIONMOUSEDOWN = "Glue Character Customization Mouse Down"
	, GLUECHARCUSTOMIZATIONMOUSEUP = "Glue Character Customization Mouse Up"
	, GLUECHARCUSTOMIZATIONMOUSEOVER = "Glue Character Customization Mouse Over"
	, GLUESCROLLBUTTONMOUSEDOWN = "Glue Scroll Button Mouse Down"
	, GLUESCROLLBUTTONMOUSEUP = "Glue Scroll Button Mouse Up"
	, GLUESCROLLBUTTONMOUSEOVER = "Glue Scroll Button Mouse Over"
	, GAMEABILITYBUTTONMOUSEDOWN = "Game Ability Button Mouse Down"
	, GAMESPELLBUTTONMOUSEDOWN = "Game Spell Button Mouse Down"
	, GAMEWINDOWOPEN = "Game Window Open"
	, GAMEWINDOWCLOSE = "Game Window Close"
	, GAMEDIALOGOPEN = "Game Dialog Open"
	, GAMEDIALOGCLOSE = "Game Dialog Close"
	, GAMENEWWINDOWTAB = "GameNEW WindowTAB"
	, GAMESCREENSMALLBUTTONMOUSEDOWN = "Game Screen Small Button Mouse Down"
	, GAMESCREENSMALLBUTTONMOUSEUP = "Game Screen Small Button Mouse Up"
	, GAMESCREENSMALLBUTTONMOUSEOVER = "Game Screen Small Button Mouse Over"
	, GAMESCREENMEDIUMBUTTONMOUSEDOWN = "Game Screen Medium Button Mouse Down"
	, GAMESCREENMEDIUMBUTTONMOUSEUP = "Game Screen Medium Button Mouse Up"
	, GAMESCREENMEDIUMBUTTONMOUSEOVER = "Game Screen Medium Button Mouse Over"
	, GAMESCREENLARGEBUTTONMOUSEDOWN = "Game Screen Large Button Mouse Down"
	, GAMESCREENLARGEBUTTONMOUSEUP = "Game Screen Large Button Mouse Up"
	, GAMESCREENLARGEBUTTONMOUSEOVER = "Game Screen Large Button Mouse Over"
	, GAMETARGETFRIENDLYUNIT = "Game Target Friendly Unit"
	, GAMETARGETHOSTILEUNIT = "Game Target Hostile Unit"
	, GAMETARGETNEUTRALUNIT = "Game Target Neutral Unit"
	, GAMEHIGHLIGHTFRIENDLYUNIT = "Game Highlight Friendly Unit"
	, GAMEHIGHLIGHTHOSTILEUNIT = "Game Highlight Hostile Unit"
	, GAMEHIGHLIGHTNEUTRALUNIT = "Game Highlight Neutral Unit"
	, GAMEINITIALATTACK = "Game Initial Attack"
	, GAMEERROROUTOFRANGE = "E: Out of Range"
	, GAMEERROROUTOFMANA = "E: Out of Mana"
	, GAMEERRORUNABLETOEQUIP = "E: Unable to Equip"
	, GAMEERRORINVALIDTARGET = "E: Invalid Target"
	, ACTIONBARBUTTONDOWN = "Action Bar Button Down"
	, MAINBUTTONBARMENU = "Main Button Bar Menu"
	, MINIMAPZOOMOUT = "MiniMap Zoom Out"
	, MINIMAPZOOMIN = "MiniMap Zoom In"
	, MINIMAPOPEN = "MiniMap Open"
	, MINIMAPCLOSE = "MiniMap Close"
	, BAGMENUBUTTONPRESS = "Bag Menu Button Press"
	, ITEMWEAPONSOUND = "Item Weapon"
	, ITEMARMORSOUND = "Item Armor"
	, ITEMGENERICSOUND = "Item Generic"
	, LEVELUP = "Level Up"
	, LEVELUPSOUND = "Level Up (2)"
	, GLUECREATECHARACTERBUTTON = "Glue Create Character Button"
	, GLUEENTERWORLDBUTTON = "Glue Enter World Button"
	, SPELLBOOKOPEN = "Spell Book Open"
	, SPELLBOOKCLOSE = "Spell Book Close"
	, SPELLBOOKCHANGEPAGE = "Spell Book Change Page"
	, PAPERDOLLOPEN = "Paper Doll Open"
	, PAPERDOLLCLOSE = "Paper Doll Close"
	, QUESTADDED = "Quest Added"
	, QUESTCOMPLETED = "Quest Completed"
	, QUESTLOGOPEN = "Quest Log Open"
	, QUESTLOGCLOSE = "Quest Log Close"
	, GLUEGENERICBUTTONPRESS = "Glue Generic Button Press"
	, GAMEGENERICBUTTONPRESS = "Game Generic Button Press"
	, INTERFACESOUND_MONEYFRAMEOPEN = "Money Frame Open"
	, INTERFACESOUND_MONEYFRAMECLOSE = "Money Frame Close"
	, INTERFACESOUND_CHARWINDOWOPEN = "Char Window Open"
	, INTERFACESOUND_CHARWINDOWCLOSE = "Char Window Close"
	, INTERFACESOUND_CHARWINDOWTAB = "Char Window Tab"
	, INTERFACESOUND_GAMEMENUOPEN = "Game Menu Open"
	, INTERFACESOUND_GAMEMENUCLOSE = "Game Menu Close"
	, INTERFACESOUND_LOSTTARGETUNIT = "Lost Target Unit"
	, INTERFACESOUND_BACKPACKOPEN = "Backpack Open"
	, INTERFACESOUND_BACKPACKCLOSE = "Backpack Close"
	, INTERFACESOUND_GAMESCROLLBUTTON = "Game Scroll Button"
	, INTERFACESOUND_CURSORGRABOBJECT = "Cursor Grab Object"
	, INTERFACESOUND_CURSORDROPOBJECT = "Cursor Drop Object"
	, SHEATHINGSHIELDSHEATHE = "Shield Sheathe"
	, SHEATHINGWOODWEAPONSHEATHE = "Wood Weapon Sheathe"
	, SHEATHINGMETALWEAPONSHEATHE = "Metal Weapon Sheathe"
	, SHEATHINGWOODWEAPONUNSHEATHE = "Wood Weapon Unsheathe"
	, SHEATHINGMETALWEAPONUNSHEATHE = "Metal Weapon Unsheathe"
	, SHEATHINGSHIELDUNSHEATHE = "Sheild Unsheathe"
	, ITEMGENERICSOUND = "Item Generic Sound"
	, MONEYFRAMEOPEN = "Money Frame Open (2)"
	, MONEYFRAMECLOSE = "Money Frame Close (2)"
	, LOOTWINDOWOPEN = "Loot Window Open"
	, LOOTWINDOWCLOSE = "Loot Window Close"
	, LOOTWINDOWCOINSOUND = "Loot Window Coin Sound"
	, GAMEABILITYACTIVATE = "Game Ability Activate"
	, GAMESPELLACTIVATE = "Game Spell Activate"
	, gsTitleEnterWorld = "Title Enter World"
	, gsTitleOptions = "Title Options"
	, gsTitleQuit = "Title Quit"
	, gsTitleCredits = "Title Credits"
	, gsTitleIntroMovie = "Title Intro Movie"
	, gsTitleOptionScreenResolution = "Title Option Screen Resolution"
	, gsTitleOption16bit = "Title Option 16bit"
	, gsTitleOption32bit = "Title Option 32bit"
	, gsTitleOptionOpenGL = "Title Option OpenGL"
	, gsTitleOptionDirect3D = "Title Option Direct3D"
	, gsTitleOptionFullScreenMode = "Title Option Full Screen Mode"
	, gsTitleOptionOK = "Title Option OK"
	, gsTitleOptionExit = "Title Option Exit"
	, gsLogin = "Login"
	, gsLoginNewAccount = "Login New Account"
	, gsLoginChangeRealm = "Login Change Realm"
	, gsLoginExit = "Login Exit"
	, gsLoginChangeRealmOK = "Login Change Realm OK"
	, gsLoginChangeRealmSelect = "Login Change Realm Select"
	, gsLoginChangeRealmCancel = "Login Change Realm Cancel"
	, gsCharacterSelection = "Character Selection"
	, gsCharacterSelectionEnterWorld = "Character Selection Enter World"
	, gsCharacterSelectionDelCharacter = "Character Selection Del Character"
	, gsCharacterSelectionAcctOptions = "Character Selection Acct Options"
	, gsCharacterSelectionExit = "Character Selection Exit"
	, gsCharacterSelectionCreateNew = "Character Selection Create New"
	, gsCharacterCreationClass = "Character Creation Class"
	, gsCharacterCreationRace = "Character Creation Race"
	, gsCharacterCreationGender = "Character Creation Gender"
	, gsCharacterCreationLook = "Character Creation Look"
	, gsCharacterCreationCreateChar = "Character Creation Create Char"
	, gsCharacterCreationCancel = "Character Creation Cancel"
	, igAbilityOpen = "Ability Open"
	, igAbilityClose = "Ability Close"
	, igAbiliityPageTurn = "Abiliity Page Turn"
	, igAbilityIconPickup = "Ability Icon Pick Up"
	, igAbilityIconDrop = "Ability Icon Drop"
	, igCharacterInfoOpen = "Character Info Open"
	, igCharacterInfoClose = "Character Info Close"
	, igCharacterInfoTab = "Character Info Tab"
	, igCharacterInfoScrollUp = "Character Info Scroll Up"
	, igCharacterInfoScrollDown = "Character Info Scroll Down"
	, igCharacterNPCSelect = "Character NPC Select"
	, igCharacterNPCDeselect = "Character NPC Deselect"
	, igCharacterSelect = "Character Select"
	, igCharacterDeselect = "Character Deselect"
	, igChatEmoteButton = "Chat Emote Button"
	, igChatScrollUp = "Chat Scroll Up"
	, igChatScrollDown = "Chat Scroll Down"
	, igChatBottom = "Chat Bottom"
	, igCreatureNeutralSelect = "Creature Neutral Select"
	, igCreatureNeutralDeselect = "Creature Neutral Deselect"
	, igCreatureAggroSelect = "Creature Aggro Select"
	, igCreatureAggroDeselect = "Creature Aggro Deselect"
	, igCurrentActiveSpell = "Current Active Spell"
	, igInventoryOepn = "Inventory Oepn"
	, igInventoryClose = "Inventory Close"
	, igInventoryRotateCharacter = "Inventory Rotate Character"
	, igBackPackOpen = "Back Pack Open"
	, igBackPackClose = "Back Pack Close"
	, igBackPackCoinSelect = "Back Pack Coin Select"
	, igBackPackCoinOK = "Back Pack Coin OK"
	, igBackPackCoinCancel = "Back Pack Coin Cancel"
	, igMainMenuOpen = "Main Menu Open"
	, igMainMenuClose = "Main Menu Close"
	, igMainMenuOption = "Main Menu Option"
	, igMainMenuLogout = "Main Menu Logout"
	, igMainMenuQuit = "Main Menu Quit"
	, igMainMenuContinue = "Main Menu Continue"
	, igMainMenuOptionCheckBoxOn = "Main Menu Option Check Box On"
	, igMainMenuOptionCheckBoxOff = "Main Menu Option Check Box Off"
	, igMainMenuOptionFaerTab = "Main Menu Option Faer Tab"
	, igMiniMapOpen = "Mini Map Open"
	, igMiniMapClose = "Mini Map Close"
	, igMiniMapZoomIn = "Mini Map Zoom In"
	, igMiniMapZoomOut = "Mini Map Zoom Out"
	, igPlayerInvite = "Player Invite"
	, igPlayerInviteAccept = "Player Invite Accept"
	, igPlayerInviteDecline = "Player Invite Decline"
	, igQuestListOpen = "Quest List Open"
	, igQuestListClose = "Quest List Close"
	, igQuestListSelect = "Quest List Select"
	, igQuestListComplete = "Quest List Complete"
	, igQuestCancel = "Quest Cancel"
	, igQuestLogOpen = "Quest Log Open (2)"
	, igQuestLogClose = "Quest Log Close (2)"
	, igQuestLogAbandonQuest = "Quest Log Abandon Quest"
	, igQuestFailed = "Quest Failed"
	, igSpellBookOpen = "Spell Book Open (2)"
	, igSpellBookClose = "Spell Book Close (2)"
	, igSpellBokPageTur = "Spell Bok Page Tur"
	, igSpellBookSpellIconPickup = "Spell Book Spell Icon Pick Up"
	, igSpellBookSpellIconDrop = "Spell Book Spell Icon Drop"
	, igSocialOepn = "Social Oepn"
	, igSocialClose = "Social Close"
	, TalentScreenOpen = "Talent Screen Open"
	, TalentScreenClose = "Talent Screen Close"
	, UChatScrollButton = "U Chat Scroll Button"
	, Deathbind = "Deathbind"
	, LOOTWINDOWOPENEMPTY = "Loot Window Open Empty"
	, TaxiNodeDiscovered = "Taxi Node Disc Overed"
	, UnwrapGift = "Unwrap Gift"
	, TellMessage = "Tell Message"
	, WriteQuest = "Write Quest"
	, MapPing = "Map Ping"
	, igBonusBarOpen = "Bonus Bar Open"
	, FriendJoinGame = "Friend Join Game"
	, Fishing = "Fishing"
	-- Exploration sounds
	, HumanExploration = "Human Exploration"
	, OrcExploration = "Orc Exploration"
	, UndeadExploration = "Undead Exploration"
	, TaurenExploration = "Tauren Exploration"
	, TrollExploration = "Troll Exploration"
	, NightElfExploration = "Night Elf Exploration"
	, GnomeExploration = "Gnome Exploration"
	, DwarfExploration = "Dwarf Exploration"
	, igPVPUpdate = "PVP Update"
	, ReadyCheck = "Ready Check"
	, RaidWarning = "Raid Warning"
	, AuctionWindowOpen = "Auction Window Open"
	, AuctionWindowClose = "Auction Window Close"
}

local SharedMedia = LibStub:GetLibrary("LibSharedMedia-3.0", true)
if SharedMedia then
	for k, v in pairs(kPlaySoundValues) do
		-- Key and value is reversed since the value is the displayed string
		SharedMedia:Register("playsound", v, k)
	end
end
